@@ -16,13 +16,11 @@
 
 #include "kgpgtextorfiletransaction.h"
 
-#include <KUrl>
+#include <QUrl>
 #include <QObject>
 #include <QString>
 #include <QStringList>
 
-class QProcess;
-
 /**
  * @brief sign the given text or files
  */
@@ -58,7 +56,7 @@ public:
 	 * @warning GnuPG can currently handle only one file per invocation for
 	 * signing, so files may only contain one single file.
 	 */
-	KGpgSignText(QObject *parent, const QString &signId, const KUrl::List &files, const SignOptions &options = DefaultSignature, const QStringList &extraOptions = QStringList());
+	KGpgSignText(QObject *parent, const QString &signId, const QList<QUrl> &files, const SignOptions &options = DefaultSignature, const QStringList &extraOptions = QStringList());
 
 	/**
 	 * @brief destructor
@@ -72,7 +70,7 @@ public:
 	QStringList signedText() const;
 
 protected:
-	virtual QStringList command() const Q_DECL_OVERRIDE;
+	QStringList command() const Q_DECL_OVERRIDE;
 
 private:
 	int m_fileIndex;
